@@ -11,12 +11,6 @@ has tvrealm       => ( isa => 'Str',  is => 'ro', default => 'Web Password'
 
 requires qw/ua username password/;
 
-after credentials => sub {
-    my $self = shift;
-
-    $self->ua->credentials($self->tvhost, $self->tvrealm, $self->username, $self->password);
-};
-
 base_url     'tvurl';
 authenticate 1;
 
