@@ -20,10 +20,10 @@ around BUILDARGS => sub {
 
     my $args = $class->$orig(@_);
     my $oauth_urls = delete $args->{oauth_urls} || {
-        request_token_url  => "http://api.twitter.com/oauth/request_token",
-        authentication_url => "http://api.twitter.com/oauth/authenticate",
-        authorization_url  => "http://api.twitter.com/oauth/authorize",
-        access_token_url   => "http://api.twitter.com/oauth/access_token",
+        request_token_url  => "https://api.twitter.com/oauth/request_token",
+        authentication_url => "https://api.twitter.com/oauth/authenticate",
+        authorization_url  => "https://api.twitter.com/oauth/authorize",
+        access_token_url   => "https://api.twitter.com/oauth/access_token",
         xauth_url          => "https://api.twitter.com/oauth/access_token",
     };
 
@@ -33,6 +33,13 @@ around BUILDARGS => sub {
 has consumer_key    => ( isa => 'Str', is => 'ro', required => 1 );
 has consumer_secret => ( isa => 'Str', is => 'ro', required => 1 );
 
+after BUILD => sub {
+    my $self = shift;
+
+    eval "require Crypt::SSLeay; Crypt::SSLeay->VERSION >= 0.50"
+        || croak "Crypt::SSLeay 0.50 or later required for OAuth support";
+};
+
 # url attributes
 for my $attribute ( qw/authentication_url authorization_url request_token_url access_token_url xauth_url/ ) {
     has $attribute => (
@@ -107,8 +114,11 @@ sub _request_request_token {
         %params,
     );
 
-    my $res = $self->ua->get($request->to_url);
-    die "GET $uri failed: ".$res->status_line
+    my $msg = HTTP::Request->new(GET => $uri);
+    $msg->header(authorization => $request->to_authorization_header);
+
+    my $res = $self->_send_request($msg);
+    croak "GET $uri failed: ".$res->status_line
         unless $res->is_success;
 
     # reuse $uri to extract parameters from the response content
@@ -132,8 +142,11 @@ sub request_access_token {
         %params, # verifier => $verifier
     );
 
-    my $res = $self->ua->get($request->to_url);
-    die "GET $uri failed: ".$res->status_line
+    my $msg = HTTP::Request->new(GET => $uri);
+    $msg->header(authorization => $request->to_authorization_header);
+
+    my $res = $self->_send_request($msg);
+    croak "GET $uri failed: ".$res->status_line
         unless $res->is_success;
 
     # discard request tokens, they're no longer valid
